/* GCC */

#include <stdio.h>
#include <stdlib.h>
#include <vector>
#include <map>

using namespace std;

//   ( )    p0p1  p0p2
inline int product(pair<int, int> p0, pair<int, int> p1, pair<int, int> p2)
{
    return (p1.first - p0.first) * (p2.second - p0.second) - (p1.second - p0.second) * (p2.first - p0.first);
}

//  n=0,  0;      ,   n
inline int sign(int n)
{
    if (n > 0)
        return 1;
    else if (n < 0)
        return -1;
    else
        return 0;
}

//    ,     a1  a2
inline void coeffs(pair<int, int> a1, pair<int, int> a2, long long &ca, long long &cb, long long &cc)
{
    ca = a1.second - a2.second;
    cb = a2.first - a1.first;
    cc = a1.first * a2.second - a1.second * a2.first;
}

//     p   ax+by+c,   sqrt(a*a+b*b) 
inline int distance(long long a, long long b, long long c, pair<int, int> p)
{
    return abs(a * p.first + b * p.second + c);
}

// ,    a1a2  b1b2 ( , ,    )
inline bool intersect(pair<int, int> a1, pair<int, int> a2, pair<int, int> b1, pair<int, int> b2)
{
    long long ca, cb, cc, da, db, dc;
    coeffs(a1, a2, ca, cb, cc);
    coeffs(b1, b2, da, db, dc);
    if (ca * db == cb * da) //  ,   , 
    {
        if (ca * dc != cc * da || cb * dc != cc * db) //    ,    
           return false;
        else //   ,   
        {
            int l1, m1, l2, m2;
            if (a1.first != a2.first) //     ,     
            {
                l1 = min(a1.first, a2.first), l2 = max(a1.first, a2.first);
                m1 = min(b1.first, b2.first), m2 = max(b1.first, b2.first);
            }
            else //    ,     
            {
                l1 = min(a1.second, a2.second), l2 = max(a1.second, a2.second);
                m1 = min(b1.second, b2.second), m2 = max(b1.second, b2.second);
            }
            return !(m2 <= l1 || m1 >= l2); // ,    
        }
    }
    else //  ,   ,   
    {
        // ϳ       ,
        //  ,       
        int pb1 = sign(ca * b1.first + cb * b1.second + cc);
        int pb2 = sign(ca * b2.first + cb * b2.second + cc);
        int pa1 = sign(da * a1.first + db * a1.second + dc);
        int pa2 = sign(da * a2.first + db * a2.second + dc);

        switch (pb1 * pb2)
        {
            case 1: //   b1  b2       a1a2,   
                return false;
            case -1: //   b1  b2       a1a2,      ,
                return pa1 * pa2 <= 0; //   a1  a2        b1b2
            case 0: //     b1  b2    a1a2,      ,
                return pa1 * pa2 == -1; //   a1  a2       b1b2
        }
    }
}

//           ( ,  ,  ),  
//      c;   line  true  false   ,    
//  (  c)    
vector<int> hull(const vector<pair<int, int> > &c, bool &line)
{
    int n = c.size();
    vector<int> result; //      

    //      (      )        
    int minInd = 0;
    for (int i = 1; i < n; i++)
        if (c[i].second < c[minInd].second || c[i].second == c[minInd].second && c[i].first < c[minInd].first)
           minInd = i;
    result.push_back(minInd);

    line = true; //  

    if (n == 1)
       return result;

    // used[i]   true    ,   i      ,   i!=minInd
    vector<bool> used;
    used.resize(n, false);

    int prevInd = minInd; // ,         
    while (true)
    {
        int curInd = (prevInd == minInd) ? (minInd + 1) % n : minInd; //  -  
        for (int i = 0; i < n; i++) //          
        {
            if (!used[i] && i != prevInd && i != minInd) // ֳ  ,         
            {
                int p = product(c[prevInd], c[curInd], c[i]); //    ,    
                if (p < 0 || //       
                    p == 0 && curInd == minInd || //            - (,    ,      minInd)
                    p == 0 && abs(c[prevInd].first - c[i].first) + abs(c[prevInd].second - c[i].second) < //       ,  ,   ,
                              abs(c[prevInd].first - c[curInd].first) + abs(c[prevInd].second - c[curInd].second)) //    prevInd,   
                {
                    curInd = i; //  -
                }
            }
        }
        if (curInd == minInd) //       , 
            break;

        //      
        used[curInd] = true;
        result.push_back(curInd);
        prevInd = curInd;
    }

    //     , ,         
    for (int i = 0; i < result.size(); i++)
        if (product(c[result[i]], c[result[(i + 1) % n]], c[result[(i + 2) % n]]) != 0)
        {
            line = false;
            break;
        }

    return result;
}

//   answer     hull       pp     pq
void levelLine(const vector<pair<int, int> > &hull, int pp, int pq, vector<pair<int, int> > &answer)
{
    if (pp <= pq)
        for (int i = pp; i <= pq; i++)
            answer.push_back(hull[i]);
    else
        for (int i = pp; i >= pq; i--)
            answer.push_back(hull[i]);
}

//   answer      hull       pp     pq,    pq;
//  a     ( pq),   b     
void levelHull(const vector<pair<int, int> > &hull, int pp, int pq, int &a, int &b, vector<pair<int, int> > &answer)
{
    int n = hull.size();
    if ((pp + 1) % n == pq) //   pq     pp,       
    {
        for (int i = pp + (pq > 0 ? n : 0); i >= pq + 1; i--)
            answer.push_back(hull[i % n]);
        b = (pq + 1) % n;
        a = pq;
    }
    else //        
    {
        for (int i = pp + (pp > 0 ? 0 : n); i <= pq + n - 1; i++)
            answer.push_back(hull[i % n]);
        b = (pq + n - 1) % n;
        a = pq;
    }
}

//  ,    answer     pp  pq   hulls[l]  ;
//  lastLine   ,        ( )
void level(const vector<vector<pair<int, int> > > &hulls, int l, int pp, int pq, bool lastLine, vector<pair<int, int> > &answer)
{
    int a, b;
    if (l == hulls.size() - 1) //       
    {
        if (lastLine) //     
            levelLine(hulls[l], pp, pq, answer); //  
        else //      
        {
            levelHull(hulls[l], pp, pq, a, b, answer); //   (  )
            answer.push_back(hulls[l][a]); //   
        }
    }
    else if (l == hulls.size() - 2 && lastLine) //      ,     
    {
        levelHull(hulls[l], pp, pq, a, b, answer); //   (  )
        int lnmax = hulls[l + 1].size() - 1; //       

        // ,        (      )
        //    ,     
        if (!intersect(hulls[l][a], hulls[l + 1][0], hulls[l][b], hulls[l + 1][lnmax]) &&
            !intersect(hulls[l][a], hulls[l + 1][0], hulls[l + 1][0], hulls[l + 1][lnmax]) &&
            !intersect(hulls[l + 1][0], hulls[l + 1][lnmax], hulls[l][b], hulls[l + 1][lnmax]))
        {
            level(hulls, l + 1, lnmax, 0, lastLine, answer);
        }
        else
        {
            level(hulls, l + 1, 0, lnmax, lastLine, answer);
        }

        answer.push_back(hulls[l][a]); //      
    }
    else //           
    {
        levelHull(hulls[l], pp, pq, a, b, answer); //      (  )
        int nsize = hulls[l + 1].size(); //    

        //     ab     
        long long ca, cb, cc;
        coeffs(hulls[l][a], hulls[l][b], ca, cb, cc);
        int mini = 0, mind = distance(ca, cb, cc, hulls[l + 1][mini]); //     ()   
        for (int i = 1; i < nsize; i++)
        {
            int cur = distance(ca, cb, cc, hulls[l + 1][i]);
            if (cur < mind)
            {
                mind = cur;
                mini = i;
            }
        }

        // np   ,  nq  nr   ,   ,    nr, np, nq    
        //      ,         a, b (    )
        int np = mini, nq, nr;
        if (b == (a + 1) % hulls[l].size())
        {
            nq = (np + 1) % nsize;
            nr = (np - 1 + nsize) % nsize;
        }
        else
        {
            nq = (np - 1 + nsize) % nsize;
            nr = (np + 1) % nsize;
        }

        //        (     ),
        //     ,     
        if (!intersect(hulls[l][a], hulls[l + 1][np], hulls[l][b], hulls[l + 1][nq]))
            level(hulls, l + 1, nq, np, lastLine, answer);
        else
            level(hulls, l + 1, np, nr, lastLine, answer);

        answer.push_back(hulls[l][a]); //      
    }
}

int main()
{
    freopen("polyline.in", "r", stdin);
    freopen("polyline.out", "w", stdout);

    vector<pair<int, int> > curc; //  curc   ,      
    map<pair<int, int>, int> m; //  ,        (  )   

    //  
    int n;
    scanf("%d", &n);
    for (int i = 0; i < n; i++)
    {
        int x, y;
        scanf("%d%d", &x, &y);
        curc.push_back(make_pair(x, y));
        m[make_pair(x, y)] = i + 1;
    }

    vector<vector<pair<int, int> > > hulls; //         
    bool line; // ϳ     ,      ( )

    //   
    while (curc.size() > 0) //     
    {
        vector<int> h = hull(curc, line); //     (  )
        vector<pair<int, int> > addc, newc; //     (  )  ,     
        vector<bool> used; // used[k]   true    ,     k    
        used.resize(curc.size(), false); //   used

        for (int i = 0; i < h.size(); i++)
        {
            addc.push_back(curc[h[i]]);
            used[h[i]] = true;
        }

        for (int i = 0; i < curc.size(); i++)
            if (!used[i])
               newc.push_back(curc[i]);

        hulls.push_back(addc);
        curc = newc;
    }

    if (hulls.size() == 1 && line) //       ,    
        printf("0");
    else //       ,  
    {
        vector<pair<int, int> > answer;
        level(hulls, 0, 0, 1, line, answer); //       answer
        for (int i = 0; i < n; i++) //  
        {
            if (i > 0)
               printf(" ");
            printf("%d", m[answer[i]]);
        }
    }
    printf("\n");
}
